@@ -272,7 +272,7 @@ void  World::registerCallbacks()
 	Dispatcher *igclass = igd->addSubdispatch(ClassDispatcher::newAnonymous(_con));
 	Dispatcher *sightd = igclass->addSubdispatch(new EncapDispatcher("sight"), "sight");
 	
-	Dispatcher *ed = sightd->addSubdispatch(new TypeDispatcher("entity", "object"));
+	Dispatcher *ed = sightd->addSubdispatch(new ObjectDispatcher("entity"));
 	// sight of game-entities (rather important this!)
 	ed->addSubdispatch(new SignalDispatcher2<Atlas::Objects::Operation::Sight,
 		Atlas::Objects::Entity::GameEntity>("world", 
@@ -286,7 +286,8 @@ void  World::registerCallbacks()
 	// the CREATE which encapsulates the entity.
 	//Dispatcher *cr = od->addSubdispatch(new ClassDispatcher("create", "create"));
 	Dispatcher *cr = opclass->addSubdispatch(new EncapDispatcher("create"), "create");
-	cr->addSubdispatch( new SignalDispatcher2<Atlas::Objects::Operation::Create,
+	cr->addSubdispatch( new SignalDispatcher3<Atlas::Objects::Operation::Sight,
+                Atlas::Objects::Operation::Create,
 		Atlas::Objects::Entity::GameEntity>("world", 
 		SigC::slot(*this, &World::recvSightCreate)
 	));
@@ -298,13 +299,15 @@ void  World::registerCallbacks()
 	);
 	
 	// sight of set operations
-	opclass->addSubdispatch( new SignalDispatcher<Atlas::Objects::Operation::Set>("set", 
+	opclass->addSubdispatch( new SignalDispatcher2<
+                Atlas::Objects::Operation::Sight, Atlas::Objects::Operation::Set>("set", 
 		SigC::slot(*this, &World::recvSightSet)),
 		"set"
 	);
 	
 	// sight of move operations
-	opclass->addSubdispatch( new SignalDispatcher<Atlas::Objects::Operation::Move>("move", 
+	opclass->addSubdispatch( new SignalDispatcher2<Atlas::Objects::Operation::Sight,
+                Atlas::Objects::Operation::Move>("move", 
 		SigC::slot(*this, &World::recvSightMove)),
 		"move"
 	);
@@ -404,13 +407,17 @@ void World::recvSightObject(const Atlas::Objects::Operation::Sight &sight,
 		// just pull it in
 		lookup(ci->asString());
 	}
+        
+    GotTime.emit(sight.getSeconds());
 }
 
-void World::recvSightCreate(const Atlas::Objects::Operation::Create &cr,
+void World::recvSightCreate(const Atlas::Objects::Operation::Sight& sight,
+        const Atlas::Objects::Operation::Create &cr,
 	const Atlas::Objects::Entity::GameEntity &ge)
 {	
 	Atlas::Objects::Operation::Sight st;
         st.setFrom(cr.getFrom());
+        st.setSeconds(sight.getSeconds());
 	_pendingInitialSight.insert(ge.getId());
     
 	recvSightObject(st, ge);
@@ -443,7 +450,8 @@ void World::recvSightDelete(const Atlas::Objects::Operation::Delete &del)
 	delete victim;
 }
 
-void World::recvSightMove(const Atlas::Objects::Operation::Move &mv)
+void World::recvSightMove(const Atlas::Objects::Operation::Sight &sight,
+    const Atlas::Objects::Operation::Move &mv)
 {
     if (!hasArg(mv, "id")) {
 	Eris::log(LOG_ERROR, "received SIGHT(MOVE) with no ID argument");
@@ -462,6 +470,8 @@ void World::recvSightMove(const Atlas::Objects::Operation::Move &mv)
 			throw UnknownEntity("Unknown entity at move", mv.getFrom());
 	} else
 		e->recvMove(mv);
+                
+    GotTime.emit(sight.getSeconds());
 }
 
 void World::recvSoundTalk(const Atlas::Objects::Operation::Sound &snd,
@@ -556,7 +566,8 @@ void World::recvDisappear(const Atlas::Objects::Operation::Disappearance &ds)
 	}
 }
 
-void World::recvSightSet(const Atlas::Objects::Operation::Set &set)
+void World::recvSightSet(const Atlas::Objects::Operation::Sight &sight,
+    const Atlas::Objects::Operation::Set &set)
 {
 	Eris::log(LOG_DEBUG, "processing IG sight(set)");
 	
@@ -568,6 +579,7 @@ void World::recvSightSet(const Atlas::Objects::Operation::Set &set)
 	}
 	
 	e->recvSet(set);
+    GotTime.emit(sight.getSeconds());
 }
 
 void World::recvErrorLook(const Atlas::Objects::Operation::Look &lk)
